@@ -42,36 +42,34 @@ namespace extractor
 
 struct ExtractorConfig final : storage::IOConfig
 {
-    ExtractorConfig() noexcept : IOConfig(
-                                     {
-                                         "",
-                                     },
-                                     {},
-                                     {".osrm",
-                                      ".osrm.restrictions",
-                                      ".osrm.names",
-                                      ".osrm.tls",
-                                      ".osrm.tld",
-                                      ".osrm.geometry",
-                                      ".osrm.nbg_nodes",
-                                      ".osrm.ebg_nodes",
-                                      ".osrm.timestamp",
-                                      ".osrm.edges",
-                                      ".osrm.ebg",
-                                      ".osrm.ramIndex",
-                                      ".osrm.fileIndex",
-                                      ".osrm.turn_duration_penalties",
-                                      ".osrm.turn_weight_penalties",
-                                      ".osrm.turn_penalties_index",
-                                      ".osrm.enw",
-                                      ".osrm.properties",
-                                      ".osrm.icd",
-                                      ".osrm.cnbg",
-                                      ".osrm.cnbg_to_ebg",
-                                      ".osrm.maneuver_overrides"}),
-                                 requested_num_threads(0),
-                                 parse_conditionals(false),
-                                 use_locations_cache(true)
+    ExtractorConfig() noexcept
+        : IOConfig(
+              {
+                  "",
+              },
+              {},
+              {".osrm.nbg",
+               ".osrm.restrictions",
+               ".osrm.names",
+               ".osrm.tls",
+               ".osrm.tld",
+               ".osrm.geometry",
+               ".osrm.nbg_nodes",
+               ".osrm.ebg_nodes",
+               ".osrm.timestamp",
+               ".osrm.edges",
+               ".osrm.ebg",
+               ".osrm.ramIndex",
+               ".osrm.fileIndex",
+               ".osrm.turn_duration_penalties",
+               ".osrm.turn_weight_penalties",
+               ".osrm.turn_penalties_index",
+               ".osrm.enw",
+               ".osrm.properties",
+               ".osrm.icd",
+               ".osrm.cnbg",
+               ".osrm.cnbg_to_ebg",
+               ".osrm.maneuver_overrides"})
     {
     }
 
@@ -85,16 +83,15 @@ struct ExtractorConfig final : storage::IOConfig
     std::vector<boost::filesystem::path> location_dependent_data_paths;
     std::string data_version;
 
-    unsigned requested_num_threads;
-    unsigned small_component_size;
+    unsigned requested_num_threads = 0;
+    unsigned small_component_size = 1000;
 
-    bool generate_edge_lookup;
-
-    bool use_metadata;
-    bool parse_conditionals;
-    bool use_locations_cache;
+    bool use_metadata = false;
+    bool parse_conditionals = false;
+    bool use_locations_cache = true;
+    bool dump_nbg_graph = false;
 };
-}
-}
+} // namespace extractor
+} // namespace osrm
 
 #endif // EXTRACTOR_CONFIG_HPP
