@@ -16,7 +16,7 @@ namespace partitioner
 struct PartitionerConfig final : storage::IOConfig
 {
     PartitionerConfig()
-        : IOConfig({".osrm", ".osrm.fileIndex", ".osrm.ebg_nodes", ".osrm.enw"},
+        : IOConfig({".osrm.fileIndex", ".osrm.ebg_nodes", ".osrm.enw"},
                    {".osrm.hsgr", ".osrm.cnbg"},
                    {".osrm.ebg",
                     ".osrm.cnbg",
@@ -44,7 +44,7 @@ struct PartitionerConfig final : storage::IOConfig
     std::size_t small_component_size;
     std::vector<std::size_t> max_cell_sizes;
 };
-}
-}
+} // namespace partitioner
+} // namespace osrm
 
 #endif // OSRM_PARTITIONER_CONFIG_HPP
